# 102017059_Aakanksha_Topsis

This package is implementation of multi-criteria decision analysis using topsis. This package will accept three arguments during file execution:

dataset.csv //file which contains the models and parameters
string of weights separated by commas(,)
string of requirements (+/-) separated by commas(,) // important install pandas,sys,operator and math libraries before installing this // You can install this package using following command pip install 102017059_Aakanksha_Topsis
